@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -15,9 +15,7 @@ KDebugSettingUtilTest::KDebugSettingUtilTest(QObject *parent)
 {
 }
 
-KDebugSettingUtilTest::~KDebugSettingUtilTest()
-{
-}
+KDebugSettingUtilTest::~KDebugSettingUtilTest() = default;
 
 void KDebugSettingUtilTest::shouldParseKdeLoggingLine_data()
 {
