@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -17,9 +17,7 @@
 namespace KDebugSettingsUtil
 {
 struct LIBKDEBUGSETTINGS_EXPORT_TEST_EXPORT LineLoggingQtCategory {
-    LineLoggingQtCategory()
-    {
-    }
+    LineLoggingQtCategory() = default;
 
     enum LoggingType { Unknown = 0, Info, Warning, Debug, Critical, All };
 
